@@ -30,10 +30,7 @@ import aws_cdk.aws_elasticloadbalancingv2
 import aws_cdk.aws_lambda
 
 
-@jsii.implements(
-    aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget,
-    aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget,
-)
+@jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget, aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
 class InstanceIdTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceIdTarget",
@@ -119,10 +116,7 @@ class InstanceTarget(
         jsii.create(InstanceTarget, self, [instance, port])
 
 
-@jsii.implements(
-    aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget,
-    aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget,
-)
+@jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget, aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
 class IpTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.IpTarget",
